@@ -17,6 +17,7 @@ var (
 		Long:              quadletPrintDescription,
 		RunE:              print,
 		ValidArgsFunction: common.AutocompleteQuadlets,
+		Aliases:           []string{"cat"},
 		Args:              cobra.ExactArgs(1),
 		Example: `podman quadlet print myquadlet.container
 podman quadlet print mypod.pod
@@ -31,7 +32,7 @@ func init() {
 	})
 }
 
-func print(cmd *cobra.Command, args []string) error {
+func print(_ *cobra.Command, args []string) error {
 	quadletContents, err := registry.ContainerEngine().QuadletPrint(registry.Context(), args[0])
 	if err != nil {
 		return err
