@@ -1,17 +1,20 @@
+//go:build linux || freebsd
+
 package integration
 
 import (
 	"encoding/json"
 	"fmt"
+	"net"
 	"path/filepath"
 	"time"
 
 	"github.com/containers/podman/v5/pkg/domain/entities"
 	. "github.com/containers/podman/v5/test/utils"
-	"github.com/containers/storage/pkg/stringid"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	. "github.com/onsi/gomega/gexec"
+	"go.podman.io/storage/pkg/stringid"
 )
 
 var _ = Describe("Podman network", func() {
@@ -272,6 +275,10 @@ var _ = Describe("Podman network", func() {
 		defer podmanTest.removeNetwork(netName)
 		Expect(network).Should(ExitCleanly())
 
+		session := podmanTest.Podman([]string{"network", "inspect", netName, "--format", "{{.Id}}"})
+		session.WaitWithDefaultTimeout()
+		netID := session.OutputToString()
+
 		ctrName := "testCtr"
 		container := podmanTest.Podman([]string{"run", "-dt", "--network", netName, "--name", ctrName, ALPINE, "top"})
 		container.WaitWithDefaultTimeout()
@@ -285,7 +292,7 @@ var _ = Describe("Podman network", func() {
 		Expect(conData[0].NetworkSettings.Networks).To(HaveLen(1))
 		Expect(conData[0].NetworkSettings.Networks).To(HaveKey(netName))
 		net := conData[0].NetworkSettings.Networks[netName]
-		Expect(net).To(HaveField("NetworkID", netName))
+		Expect(net).To(HaveField("NetworkID", netID))
 		Expect(net).To(HaveField("IPPrefixLen", 24))
 		Expect(net.IPAddress).To(HavePrefix("10.50.50."))
 
@@ -295,6 +302,27 @@ var _ = Describe("Podman network", func() {
 		Expect(rmAll).Should(ExitCleanly())
 	})
 
+	It("podman run container host interface name", func() {
+		Skip("FIXME: We need netavark >= v1.14 for host interface support")
+
+		ctrName := "testCtr"
+		vethName := "my_veth" + stringid.GenerateRandomID()[:8]
+		container := podmanTest.Podman([]string{"run", "-dt", "--network", "bridge:host_interface_name=" + vethName, "--name", ctrName, ALPINE, "top"})
+		container.WaitWithDefaultTimeout()
+		Expect(container).Should(ExitCleanly())
+
+		if !isRootless() {
+			veth, err := net.InterfaceByName(vethName)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(veth.Name).To(Equal(vethName))
+		} else {
+			session := podmanTest.Podman([]string{"unshare", "--rootless-netns", "ip", "link", "show", vethName})
+			session.WaitWithDefaultTimeout()
+			Expect(session).Should(ExitCleanly())
+			Expect(session.OutputToString()).To(ContainSubstring(vethName))
+		}
+	})
+
 	It("podman inspect container two CNI networks (container not running)", func() {
 		netName1 := "net1-" + stringid.GenerateRandomID()
 		network1 := podmanTest.Podman([]string{"network", "create", netName1})
@@ -308,6 +336,14 @@ var _ = Describe("Podman network", func() {
 		defer podmanTest.removeNetwork(netName2)
 		Expect(network2).Should(ExitCleanly())
 
+		session := podmanTest.Podman([]string{"network", "inspect", netName1, "--format", "{{.Id}}"})
+		session.WaitWithDefaultTimeout()
+		netID1 := session.OutputToString()
+
+		session = podmanTest.Podman([]string{"network", "inspect", netName2, "--format", "{{.Id}}"})
+		session.WaitWithDefaultTimeout()
+		netID2 := session.OutputToString()
+
 		ctrName := "testCtr"
 		container := podmanTest.Podman([]string{"create", "--network", fmt.Sprintf("%s,%s", netName1, netName2), "--name", ctrName, ALPINE, "top"})
 		container.WaitWithDefaultTimeout()
@@ -322,9 +358,9 @@ var _ = Describe("Podman network", func() {
 		Expect(conData[0].NetworkSettings.Networks).To(HaveKey(netName1))
 		Expect(conData[0].NetworkSettings.Networks).To(HaveKey(netName2))
 		net1 := conData[0].NetworkSettings.Networks[netName1]
-		Expect(net1).To(HaveField("NetworkID", netName1))
+		Expect(net1).To(HaveField("NetworkID", netID1))
 		net2 := conData[0].NetworkSettings.Networks[netName2]
-		Expect(net2).To(HaveField("NetworkID", netName2))
+		Expect(net2).To(HaveField("NetworkID", netID2))
 
 		// Necessary to ensure the CNI network is removed cleanly
 		rmAll := podmanTest.Podman([]string{"rm", "-t", "0", "-f", ctrName})
@@ -345,6 +381,14 @@ var _ = Describe("Podman network", func() {
 		defer podmanTest.removeNetwork(netName2)
 		Expect(network2).Should(ExitCleanly())
 
+		session := podmanTest.Podman([]string{"network", "inspect", netName1, "--format", "{{.Id}}"})
+		session.WaitWithDefaultTimeout()
+		netID1 := session.OutputToString()
+
+		session = podmanTest.Podman([]string{"network", "inspect", netName2, "--format", "{{.Id}}"})
+		session.WaitWithDefaultTimeout()
+		netID2 := session.OutputToString()
+
 		ctrName := "testCtr"
 		container := podmanTest.Podman([]string{"run", "-dt", "--network", fmt.Sprintf("%s,%s", netName1, netName2), "--name", ctrName, ALPINE, "top"})
 		container.WaitWithDefaultTimeout()
@@ -359,11 +403,11 @@ var _ = Describe("Podman network", func() {
 		Expect(conData[0].NetworkSettings.Networks).To(HaveKey(netName1))
 		Expect(conData[0].NetworkSettings.Networks).To(HaveKey(netName2))
 		net1 := conData[0].NetworkSettings.Networks[netName1]
-		Expect(net1).To(HaveField("NetworkID", netName1))
+		Expect(net1).To(HaveField("NetworkID", netID1))
 		Expect(net1).To(HaveField("IPPrefixLen", 25))
 		Expect(net1.IPAddress).To(HavePrefix("10.50.51."))
 		net2 := conData[0].NetworkSettings.Networks[netName2]
-		Expect(net2).To(HaveField("NetworkID", netName2))
+		Expect(net2).To(HaveField("NetworkID", netID2))
 		Expect(net2).To(HaveField("IPPrefixLen", 26))
 		Expect(net2.IPAddress).To(HavePrefix("10.50.51."))
 
@@ -467,7 +511,7 @@ var _ = Describe("Podman network", func() {
 		Expect(session).Should(ExitCleanly())
 
 		interval := 250 * time.Millisecond
-		for i := 0; i < 6; i++ {
+		for range 6 {
 			n := podmanTest.Podman([]string{"network", "exists", netName})
 			n.WaitWithDefaultTimeout()
 			worked = n.ExitCode() == 0
@@ -483,7 +527,7 @@ var _ = Describe("Podman network", func() {
 		Expect(top).Should(ExitCleanly())
 		interval = 250 * time.Millisecond
 		// Wait for the nginx service to be running
-		for i := 0; i < 6; i++ {
+		for range 6 {
 			// Test curl against the container's name
 			c1 := podmanTest.Podman([]string{"run", "--dns-search", "dns.podman", "--network=" + netName, NGINX_IMAGE, "curl", "web"})
 			c1.WaitWithDefaultTimeout()
@@ -547,7 +591,6 @@ var _ = Describe("Podman network", func() {
 	})
 
 	for _, opt := range []string{"-o=parent=lo", "--interface-name=lo"} {
-		opt := opt
 		It(fmt.Sprintf("podman network create/remove macvlan as driver (-d) with %s", opt), func() {
 			net := "macvlan" + stringid.GenerateRandomID()
 			nc := podmanTest.Podman([]string{"network", "create", "-d", "macvlan", opt, net})
@@ -694,7 +737,7 @@ var _ = Describe("Podman network", func() {
 		Expect(listAgain.OutputToStringArray()).Should(ContainElement("podman"))
 	})
 
-	It("podman network prune", func() {
+	It("podman network prune", Serial, func() {
 		useCustomNetworkDir(podmanTest, tempdir)
 		// Create two networks
 		// Check they are there
